View Source LlmComposer.Settings (llm_composer v0.12.0)
Defines the settings for configuring chat interactions with a language model.
This module provides a struct that includes model configuration, prompt settings, and options for function execution, enabling fine control over the chat flow and behavior.
Summary
Types
@type t() :: %LlmComposer.Settings{ api_key: String.t() | nil, auto_exec_functions: boolean(), functions: [LlmComposer.Function.t()], provider: module() | nil, provider_opts: keyword() | nil, providers: [{module(), keyword()}] | nil, stream_response: boolean(), system_prompt: String.t() | nil, track_costs: boolean(), user_prompt_prefix: String.t() }